@@ -1,6 +1,6 @@
 use common::sense;
 
-our $VERSION = '1.002';
+our $VERSION = '1.05';
 
 # ABSTRACT: Work with a deck of playing cards in the fashion engineered by Duane O'Brien of I.B.M. developerWorks.
 
@@ -138,15 +138,6 @@ package Helper::Deck {
         return($odds . ' in ' . $remaining);
     }
    
-    sub build_lc_letter_array {
-        my $self = shift;
-        return('a' .. 'z');
-    }
-    
-    sub build_uc_letter_array {
-        my $self = shift;
-        return('A' .. 'Z');
-    }
 }
  
 1;
@@ -360,30 +351,6 @@ This method returns a description of the odds as a string.  The calculate odds m
 
 =cut
 
-=head2 build_lc_letter_array
-    usage :
-    
-        Results :
-            Let r be an array of lower case letters [a - z],
-            
-        my $r = $obj->build_lc_letter_array;
-
-The build_lc_letter_array method returns an array of lower case letters [a - z].
-
-=cut
-
-=head2 build_uc_letter_array
-    usage :
-    
-        Results :
-            Let r be an array of upper case letters [A - Z],
-            
-        my $r = $obj->build_uc_letter_array;
-
-The build_uc_letter_array method returns an array of upper case letters [A - Z].
-
-=cut
-
 =head1 AUTHOR
 
 Jason McVeigh, <jmcveigh@outlook.com>
